Introduction — Balladeer 0.42.0

# Introduction

Thanks for choosing Balladeer for your next writing project!

Your job is to steer the vessel. All I did was pick the crew. And here they are:

Python

  A popular, elegant, flexible programming language.

SpeechMark

  A simple, expressive dialogue markup system.

TOML

  A structured data format. Highly specified, and widely adopted.

HTML5

  The ultimate syntax for semantic, portable, electronic documents.

CSS3

  Powerful styling rules for layouts, themes and animation.

Each of them is a force of nature. The challenge I had was to stop this bunch from fighting.

It took half a gallon of rum and three ounces of butter. They are all working together now; hardly any friction at all.

We completed our sea trials in June 2023. And now we are ready for action.

> Balladeer is a great option for every kind of mission.

> - Parser-driven interactive fiction

> - Choice-based game books

> - Multimedia web art

> - Poetry

> - Screenplay

> You’ll find Balladeer simple to handle. And she’ll take you anywhere you want to go.

> —Tundish